function fig=pokaz_obraz(varargin)

args = parse_inputs(varargin{:});

switch args.typ
    case 'nieskalowany'
        h = image(args.X);
    case 'skalowany'
        h = imagesc(args.X);
end;

axis image;
colormap(args.mapa);

if nargout
    fig=h;
end

%--------------------------------------------------
function args = parse_inputs(varargin)

iptchecknargin(1,Inf,nargin,mfilename);

args.mapa = gray(256);
args.typ = 'skalowany';

args.X = check_X(varargin{1});

if rem(nargin,2) == 1
    first_prop_arg = 2;
    for k = first_prop_arg:2:nargin
        prop_string = check_property_string(varargin{k});
        switch prop_string
            case 'mapa'
                args.mapa = check_mapa(varargin{k+1});  
            case 'typ'
                args.typ = check_typ(varargin{k+1});
            otherwise
                eid = sprintf('Images:%s:internalError',mfilename);
                msg = sprintf('Unrecognized property string: %s', ...
                               prop_string);
                error(eid,'%s',msg);
        end;
    end
end;

%--------------------------------------------------
function prop_string = check_property_string(prop_string)

if ~ischar(prop_string)
    eid = sprintf('Images:%s:invalidPropertyName',mfilename);
    msg = 'Property names must be strings.';
    error(eid,'%s',msg);
end
valid_strings = {'typ'
                 'mapa'
                 'nieskalowany'
                 'skalowany'};
idx = strmatch(lower(prop_string), valid_strings);
switch length(idx)
 case 0
    eid = sprintf('Images:%s:unknownPropertyName',mfilename);
    msg = sprintf('Unrecognized property name: ''%s''', prop_string);
    error(eid,'%s',msg);
  case 1
    prop_string = valid_strings{idx};
  otherwise
    eid = sprintf('Images:%s:ambiguousPropertyName',mfilename);
    msg = sprintf('Ambiguous property name: ''%s''', prop_string);
    error(eid,'%s',msg);
end

%--------------------------------------------------
function X = check_X(X)

if (~isnumeric(X) && ~islogical(X)) || issparse(X)
    eid = sprintf('Images:%s:invalidImage',mfilename);
    msg = 'X must be a nonsparse numeric array.';
    error(eid,'%s',msg);
end

%--------------------------------------------------
function mapa = check_mapa(mapa)

if ~isnumeric(mapa)
    eid = sprintf('Images:%s:invalidImage',mfilename);
    msg = 'Mapa must be numeric array.';
    error(eid,'%s',msg);
end
if size(mapa,2) ~= 3
    eid = sprintf('Images:%s:colormap:InvalidNumberColumns',mfilename);
    msg = 'Mapa must have 3 columns: [R,G,B].';
    error(eid,'%s',msg);
end
if min(mapa(:)) < 0 || max(mapa(:)) > 1
    eid = sprintf('Images:%s:colormap:InvalidInputRange',mfilename);
    msg = 'Mapa must have values in [0,1].';
    error(eid,'%s',msg);
end

%--------------------------------------------------
function typ = check_typ(typ)

if ~ischar(typ)
    eid = sprintf('Images:%s:invalidImage',mfilename);
    msg = 'Typ must be a string.';
    error(eid,'%s',msg);
end
